import type { Metadata } from "next";
import "@fontsource-variable/kode-mono";
import "./globals.css";
import { Footer } from "@/components/footer";
import { Header } from "@/components/header";
import { PrimaryNavigationMenu } from "@/components/primary-nav";
import { Providers } from "@/components/providers/providers";
import { ThemeProvider } from "@/components/providers/theme-provider";
import { Button } from "@/components/ui/button";
import { Toaster } from "@/components/ui/toaster";
import Link from "next/link";
import type React from "react";

export const metadata: Metadata = {
	title: "Neptune Crypto",
	description: "A fictive app",
	icons: "/neptune.svg",
};

export default function RootLayout({
	children,
}: Readonly<{
	children: React.ReactNode;
}>) {
	return (
		<html lang="en">
			<body className={"w-full min-h-screen flex flex-col items-center justify-between"}>
				<Providers>
					<Header>
						<div className={"flex flex-row flex-wrap md:flex-nowrap gap-2"}>
							<Button asChild variant={"light"}>
								<Link href={"/wallet"}><p className={"lg:text-lg"}>Wallet</p></Link>
							</Button>
							<Button asChild variant={"light"}>
								<Link href={"/dashboard"}><p className={"lg:text-lg"}>Explore cryptos</p></Link>
							</Button>
						</div>
					</Header>
					{children}
					<Toaster />
					<Footer />
				</Providers>
			</body>
		</html>
	);
}
