import { Button } from "@/components/ui/button";
import { Card, CardContent, CardDescription, CardHeader, CardTitle } from "@/components/ui/card";
import { Input } from "@/components/ui/input";
import { Bitcoin, DollarSign, LineChart, Lock, Zap } from "lucide-react";
import Link from "next/link";

export default function HomePage() {
	return (
		<div className="flex flex-col min-h-screen">
			<main className="flex-1">
				<section className="w-full py-12 md:py-16 lg:py-24 xl:py-32">
					<div className="container px-4 md:px-6">
						<div className="flex flex-col items-center space-y-4 text-center">
							<div className="space-y-2">
								<h1 className="text-3xl font-bold tracking-tighter sm:text-4xl md:text-5xl lg:text-6xl">
									Welcome to Neptune Crypto
								</h1>
								<p className="mx-auto max-w-[700px] text-gray-500 md:text-xl dark:text-gray-400">
									Your gateway to the world of cryptocurrencies. Trade, invest, and grow your digital assets with ease.
								</p>
							</div>
							<div className="space-x-4">
								<Button>Get Started</Button>
								<Button variant="outline">Learn More</Button>
							</div>
						</div>
					</div>
				</section>

				<section className="w-full py-12 md:py-16 lg:py-20 bg-card rounded">
					<div className="container px-4 md:px-6 rounded">
						<h2 className="text-3xl font-bold tracking-tighter sm:text-5xl text-center mb-12">Our Features</h2>
						<div className="grid gap-6 sm:grid-cols-2 lg:grid-cols-3">
							<Card>
								<CardHeader>
									<Bitcoin className="h-10 w-10 mb-2"/>
									<CardTitle>Multiple Cryptocurrencies</CardTitle>
									<CardDescription>Trade a wide variety of popular cryptocurrencies.</CardDescription>
								</CardHeader>
							</Card>
							<Card>
								<CardHeader>
									<Lock className="h-10 w-10 mb-2"/>
									<CardTitle>Secure Storage</CardTitle>
									<CardDescription>Your assets are protected with state-of-the-art security measures.</CardDescription>
								</CardHeader>
							</Card>
							<Card>
								<CardHeader>
									<LineChart className="h-10 w-10 mb-2"/>
									<CardTitle>Advanced Trading Tools</CardTitle>
									<CardDescription>Access powerful analytics and trading features.</CardDescription>
								</CardHeader>
							</Card>
						</div>
					</div>
				</section>

				<section className="w-full py-12 md:py-24 lg:py-32">
					<div className="container px-4 md:px-6">
						<div className="flex flex-col items-center justify-center space-y-4 text-center">
							<div className="space-y-2">
								<h2 className="text-3xl font-bold tracking-tighter sm:text-5xl">Start Trading Today</h2>
								<p className="mx-auto max-w-[600px] text-gray-500 md:text-xl lg:text-base xl:text-xl dark:text-gray-400">
									Join thousands of traders and investors on our platform. Get started with as little as $10.
								</p>
							</div>
							<div className="w-full max-w-sm space-y-2">
								<Button>
									Sign Up
									<DollarSign className="ml-2 h-4 w-4"/>
								</Button>
								<p className="text-xs text-gray-500 dark:text-gray-400">
									By signing up, you agree to our{" "}
									<Link title="Go to legal notice" className="underline underline-offset-2" href="/legal">
										Legal Notice
									</Link>
								</p>
							</div>
						</div>
					</div>
				</section>
			</main>
		</div>
	);
}