"use client";

import { CryptosTable } from "@/components/data-tables/cryptos-table";
import { WalletTable } from "@/components/data-tables/wallet-table";
import { UserDataContext } from "@/components/providers/userdata-provider";
import { Skeleton } from "@/components/ui/skeleton";
import type { IApiAllOffersRes } from "@/interfaces/api.interface";
import type { ICryptoInWalletInfo } from "@/interfaces/crypto.interface";
import type { IUserWallet } from "@/interfaces/userdata.interface";
import ApiRequest from "@/services/apiRequest";
import { useContext, useEffect, useState } from "react";

export default function WalletPage() {
	const [isLoading, setIsLoading] = useState<boolean>(true);
	const [cryptosList, setCryptosList] = useState<ICryptoInWalletInfo[]>([]);
	const userContext = useContext(UserDataContext);

	useEffect(() => {
		console.log(userContext?.userData);
		if (userContext?.userData) {
			setIsLoading(false);
		}
	}, [userContext]);

	if (isLoading || !userContext?.userData) {
		return (
			<div
				className={
					"container flex flex-col justify-center items-center min-h-64 my-6 gap-4"
				}
			>
				<h1 className={"text-2xl font-bold"}>Loading in progress ...</h1>
				<Skeleton
					className={
						"container flex flex-col justify-center items-center min-h-64 my-6 gap-4"
					}
				/>
			</div>
		);
	}

	return (
		<>
			<section
				className={
					"container flex flex-col justify-center items-center min-h-64 my-6 gap-4 rounded sm:p-2 sm:bg-card"
				}
			>
				<h1 className={"text-xl sm:text-2xl lg:text-3xl font-bold"}>Cryptos in your wallet</h1>
				<WalletTable
					walletArray={userContext.userData.wallet as unknown as IUserWallet}
				/>
			</section>
		</>
	);
}
