import {Table, TableBody, TableCaption, TableCell, TableHead, TableHeader, TableRow} from "@/components/ui/table";
import {ScrollArea} from "@/components/ui/scroll-area";
import type {IAllTrades} from "@/interfaces/crypto.interface";
import {cn} from "@/lib/utils";

interface OfferListProps {
	className?: string;
	trades: IAllTrades;
}

interface RenderRowsProps {
	data?: IAllTrades;
}

function RenderRows({ data }: RenderRowsProps) {
	if (!data || data?.length === 0) return (<TableRow>
		<TableCell className="font-medium">{" "}</TableCell>
		<TableCell>{" "}</TableCell>
		<TableCell>{"No history..."}</TableCell>
		<TableCell className="text-right">{" "}</TableCell>
	</TableRow>);

	return data.map((item, index) => (
      <TableRow key={item.Crypto.created_at.toString()}>
        <TableCell className="font-medium">{item.Giver.pseudo}</TableCell>
        <TableCell>{item.Receiver.pseudo}</TableCell>
        <TableCell>{item.Crypto.quantity}</TableCell>
        <TableCell className="text-right">${item.Crypto.value}</TableCell>
      </TableRow>
  ));
}

export function OfferList({ className, trades}: OfferListProps) {
	return (<div className={cn("bg-card text-card-foreground rounded p-2", className)}>
		<Table>
			<TableCaption>A list of recent sell offers.</TableCaption>
			<TableHeader>
				<TableRow>
					<TableHead className="w-[100px]">Seller</TableHead>
					<TableHead>Buyer</TableHead>
					<TableHead>Crypto share amount</TableHead>
					<TableHead className="text-right">$</TableHead>
				</TableRow>
			</TableHeader>
			<TableBody>
				<RenderRows data={trades}/>
			</TableBody>
		</Table>
	</div>)
}